summary refs log tree commit diff
path: root/synapse/storage
diff options
context:
space:
mode:
authorKegan Dougal <kegan@matrix.org>2015-03-06 15:12:24 +0000
committerKegan Dougal <kegan@matrix.org>2015-03-06 15:12:24 +0000
commitf260cb72cd3435d540411962a92ca2a9fd333eb1 (patch)
tree68af80d83bbbd54a6702d9015f2cb1ff8094f2cf /synapse/storage
parentAdd stub ApplicationServiceTransactionStore. Bootstrap Recoverers. Fill in st... (diff)
downloadsynapse-f260cb72cd3435d540411962a92ca2a9fd333eb1.tar.xz
Flesh out more stub functions.
Diffstat (limited to 'synapse/storage')
-rw-r--r--synapse/storage/appservice.py17
1 files changed, 15 insertions, 2 deletions
diff --git a/synapse/storage/appservice.py b/synapse/storage/appservice.py
index c1762692b9..214f6d99c5 100644
--- a/synapse/storage/appservice.py
+++ b/synapse/storage/appservice.py
@@ -343,15 +343,28 @@ class ApplicationServiceTransactionStore(SQLBaseStore):
     def __init__(self, hs):
         super(ApplicationServiceTransactionStore, self).__init__(hs)
 
-    def get_failing_appservices(self):
-        """Get a list of application services which are down.
+    def get_appservices_by_state(self, state):
+        """Get a list of application services based on their state.
 
+        Args:
+            state(ApplicationServiceState): The state to filter on.
         Returns:
             A Deferred which resolves to a list of ApplicationServices, which
             may be empty.
         """
         pass
 
+    def set_appservice_state(self, service, state):
+        """Set the application service state.
+
+        Args:
+            service(ApplicationService): The service whose state to set.
+            state(ApplicationServiceState): The connectivity state to apply.
+        Returns:
+            A Deferred which resolves to True if the state was set successfully.
+        """
+        pass
+
     def complete_appservice_txn(self, txn_id, service):
         """Completes an application service transaction.